User Guide — CEMENTO 0.8.5 documentation

Skip to main content
`Ctrl`+`K`

# User Guide

These instructions will provide you detailed instructions on how to use the CEMENTO package. It will go through installation and important considerations into CLI use and basic conversion. A section is also dedicated to scripting for folks looking to integrate CEMENTO into their python-based software. A section on basic drawing also goes through and ins-and-outs of creating ontology diagrams. The links are provided in order for an absolute beginner, but feel free to skip to a relevant section:

## Guide Sections

- Installation
  - Prerequisites
  - Installing via `pypi`
  - Installing from the Repository
- CLI Guide
  - Command Line Interface
  - Term Matching
  - Adding or Replacing Reference Ontologies
  - Custom Terms and Prefixes
- Scripting
  - Converting draw.io to `.ttl` files
  - Converting `.ttl` files to draw.io files
  - Converting draw.io to a `networkx` DiGraph
  - Using Other Modules
- Drawing Basics
  - Drawing with draw.io
  - A Walkthrough
  - In Case You Missed It